package com.install4j.api.update;

import com.install4j.runtime.installer.helper.content.Downloader;

import java.util.HashMap;
import java.util.Map;

/**
 * Enumeration class that represents the different display modes. These values are used as an argument for
 * {@link UpdateChecker#getUpdateDescriptor(String, ApplicationDisplayMode)}.
 * @author ej-technologies GmbH
 */
public class ApplicationDisplayMode {

    private static Map intValueToDisplayMode = new HashMap();

    /**
     * The invoking application runs with a Swing GUI. Displaying a proxy dialog is acceptable.
     */
    public static final ApplicationDisplayMode GUI = new ApplicationDisplayMode("GUI", Downloader.MODE_GUI);

    /**
     * The invoking application runs on the command line. Asking for proxy information on the command line
     * is acceptable.
     */
    public static final ApplicationDisplayMode CONSOLE = new ApplicationDisplayMode("Console", Downloader.MODE_CONSOLE);

    /**
     * The invoking application does not take user input from a GUI or on the command line. Proxy information
     * cannot be supplied by the user.
     */
    public static final ApplicationDisplayMode UNATTENDED = new ApplicationDisplayMode("Unattended", Downloader.MODE_UNATTENDED);

    private String description;
    private int intValue;

    private ApplicationDisplayMode(String description, int value) {
        this.description = description;
        this.intValue = value;
        intValueToDisplayMode.put(new Integer(intValue), this);
    }

    /**
     * Convert to an int value.
     * @return the int value
     */
    public int getIntValue() {
        return intValue;
    }

    /**
     * Convert int value to constant.
     * @param overwrite the int value
     * @return the constant
     */
    public static ApplicationDisplayMode getFromIntValue(int overwrite) {
        return (ApplicationDisplayMode)intValueToDisplayMode.get(new Integer(overwrite));
    }

    public String toString() {
        return description;
    }
}